# {{ toolkit }} Documentation

The documentations of the `AIGVE` library will be organized as follows.

-----------

<div class="grid cards" markdown>
- :fontawesome-solid-tree: [__`aigve`__](aigve/index.md) library for assessing AI-generated video quality
</div>

<div class="grid cards" markdown>
- :fontawesome-solid-leaf: [__`aigve.config`__](configs/index.md) for parameter configuration and management
</div>

<div class="grid cards" markdown>
- :fontawesome-solid-leaf: [__`aigve.core`__](core/index.md) for video evaluation process design
</div>

<div class="grid cards" markdown>
- :fontawesome-solid-leaf: [__`aigve.datasets`__](datasets/index.md) for dataset loading design
</div>

<div class="grid cards" markdown>
- :fontawesome-solid-leaf: [__`aigve.metrics`__](metrics/index.md) for video evaluation metrics design and building
</div>

<div class="grid cards" markdown>
- :fontawesome-solid-leaf: [__`aigve.utils`__](utils/index.md) for utility function definition
</div>

-----------